@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from __future__ import print_function
 import sys
 import argparse
 from aptly.client import Aptly
@@ -43,6 +44,7 @@ def main():
 
     group_publish = parser.add_argument_group("Action 'publish'")
     group_publish.add_argument('-c', '--config', default="/etc/aptly/publisher.yaml", help="Configuration YAML file")
+    group_publish.add_argument('--distributions', '--dists', nargs='+', help="Space-separated list of distribution to work with (including prefix), default all.")
 
     group_promote = parser.add_argument_group("Action 'promote'")
     group_promote.add_argument('--source', help="Source publish to take snapshots from")
@@ -66,7 +68,8 @@ def main():
         action_publish(client, publishmgr, config_file=args.config,
                        recreate=args.recreate,
                        force_overwrite=args.force_overwrite,
-                       publish_contents=args.publish_contents)
+                       publish_contents=args.publish_contents,
+                       publish_names=args.dists)
     elif args.action == 'promote':
         if not args.source or not args.target:
             parser.error("Action 'promote' requires both --source and --target arguments")
@@ -158,10 +161,10 @@ def action_promote(client, source, target, components=None, recreate=False,
 def action_diff(source, target, components=[], packages=True):
     diff, equal = source.compare(target, components=components)
     if not diff:
-        print "Target is up to date with source publish"
+        print("Target is up to date with source publish")
         return
 
-    print "\033[1;36m= Differencies per component\033[m"
+    print("\033[1;36m= Differencies per component\033[m")
     for component, snapshots in diff.iteritems():
         if not snapshots:
             continue
@@ -169,16 +172,16 @@ def action_diff(source, target, components=[], packages=True):
         published_source = [i for i in source.publish_snapshots if i['Component'] == component][0]['Name']
         published_target = [i for i in target.publish_snapshots if i['Component'] == component][0]['Name']
 
-        print "\033[1;33m== %s \033[1;30m(%s -> %s)\033[m" % (component, published_target, published_source)
-        print "\033[1;35m=== Snapshots:\033[m"
+        print("\033[1;33m== %s \033[1;30m(%s -> %s)\033[m" % (component, published_target, published_source))
+        print("\033[1;35m=== Snapshots:\033[m")
         for snapshot in snapshots:
-            print "    - %s" % snapshot
+            print("    - %s" % snapshot)
 
         if packages:
-            print "\033[1;35m=== Packages:\033[m"
+            print("\033[1;35m=== Packages:\033[m")
             diff_packages = source.client.do_get('/snapshots/%s/diff/%s' % (published_source, published_target))
             if not diff_packages:
-                print "\033[1;31m    - Snapshots contain same packages\033[m"
+                print("\033[1;31m    - Snapshots contain same packages\033[m")
 
             for pkg in diff_packages:
                 left = source.parse_package_ref(pkg['Left'])
@@ -202,13 +205,14 @@ def action_diff(source, target, components=[], packages=True):
                 else:
                     old = pkg['Right']
 
-                print '    - %s \033[1;30m(%s -> %s)\033[m' % (pkg_name, old, new)
+                print('    - %s \033[1;30m(%s -> %s)\033[m' % (pkg_name, old, new))
 
-        print
+        print()
 
 
 def action_publish(client, publishmgr, config_file, recreate=False,
-                   force_overwrite=False, publish_contents=False):
+                   force_overwrite=False, publish_contents=False,
+                   publish_names=None):
     snapshots = client.do_get('/snapshots', {'sort': 'time'})
 
     config = load_config(config_file)
@@ -233,7 +237,8 @@ def action_publish(client, publishmgr, config_file, recreate=False,
         )
 
     publishmgr.do_publish(recreate=recreate, force_overwrite=force_overwrite,
-                          publish_contents=publish_contents)
+                          publish_contents=publish_contents,
+                          names=publish_names)
 
 
 if __name__ == '__main__':
